@@ -20,7 +20,7 @@ def build_nginx_conf(instance):
 
     # data to substitute into the content
     longname = instance.longname
-    server_list_string = 'example.com www.example.com'
+    server_list_string = instance.settings.WWW_SERVER_NAMES
     listen_addr = instance.settings.NGINX_LISTEN_ADDR
     if isinstance(instance, Act):
         venue_path = instance.venue.venue_home
